@@ -255,9 +255,13 @@ DatePicker.prototype  = {
   initialize  : function ( h_p ) {
 
     /* arguments */
-    this._relative= h_p["relative"];
-    if (h_p["language"])
+    this._relative = h_p["relative"];
+    if (h_p["language"]) {
       this._language = h_p["language"];
+      if (this._language_close.get(this._language) === undefined) {
+        this._language = 'en';
+      }
+    }
     this._zindex = ( h_p["zindex"] ) ? parseInt(Number(h_p["zindex"])) : 999;
     if (!Object.isUndefined(h_p["keepFieldEmpty"]))
       this._keepFieldEmpty  = h_p["keepFieldEmpty"];
@@ -289,39 +293,39 @@ DatePicker.prototype  = {
       this._dateFormat = h_p["dateFormat"];
     if (Object.isFunction(h_p["cellCallback"]))
       this._cellCallback = h_p["cellCallback"];
-      this._setPositionTop  = ( h_p["setPositionTop"] ) ? parseInt(Number(h_p["setPositionTop"])) : 0;
-    this._setPositionLeft = ( h_p["setPositionLeft"] ) ? parseInt(Number(h_p["setPositionLeft"])) : 0;
     if (!Object.isUndefined(h_p["enableCloseOnBlur"]) && h_p["enableCloseOnBlur"])
       this._enableCloseOnBlur = true;
     if (!Object.isUndefined(h_p["disablePastDate"]) && h_p["disablePastDate"])
       this._disablePastDate = true;
     if (!Object.isUndefined(h_p["disableFutureDate"]) && !h_p["disableFutureDate"])
       this._disableFutureDate = false;
+    this._setPositionTop  = ( h_p["setPositionTop"] ) ? parseInt(Number(h_p["setPositionTop"])) : 0;
+    this._setPositionLeft = ( h_p["setPositionLeft"] ) ? parseInt(Number(h_p["setPositionLeft"])) : 0;
 
-    this._id_datepicker         = 'datepicker-'+ this._relative;
-    this._id_datepicker_prev    = this._id_datepicker +'-prev';
+    this._id_datepicker           = 'datepicker-'+ this._relative;
+    this._id_datepicker_prev      = this._id_datepicker +'-prev';
     this._id_datepicker_prev_year = this._id_datepicker +'-prev-year';
-    this._id_datepicker_next    = this._id_datepicker +'-next';
+    this._id_datepicker_next      = this._id_datepicker +'-next';
     this._id_datepicker_next_year = this._id_datepicker +'-next-year';
-    this._id_datepicker_hdr     = this._id_datepicker +'-header';
-    this._id_datepicker_ftr     = this._id_datepicker +'-footer';
+    this._id_datepicker_hdr       = this._id_datepicker +'-header';
+    this._id_datepicker_ftr       = this._id_datepicker +'-footer';
 
     /* build up calendar skel */
     this._div = new Element('div', {
       id      : this._id_datepicker,
       className   : 'datepicker',
-      style     : 'display: none; z-index:'+ this._zindex });
+      style     : 'display: none; z-index:'+ this._zindex
+    });
 
-//    this._div.innerHTML = '<table><thead><tr><th width="10px" id="'+ this._id_datepicker_prev +'" style="cursor: pointer;">&nbsp;&lt;&lt;&nbsp;</th><th id="'+ this._id_datepicker_hdr +'" colspan="5"></th><th width="10px" id="'+ this._id_datepicker_next +'" style="cursor: pointer;">&nbsp;&gt;&gt;&nbsp;</th></tr></thead><tbody id="'+ this._id_datepicker +'-tbody"></tbody><tfoot><td colspan="7" id="'+ this._id_datepicker_ftr +'"></td></tfoot></table>';
-      this._div.innerHTML = '<div class="datepicker-header"><table class="header"><tr><td id="'+ this._id_datepicker_prev_year +'" class="prev_year"> << </td><td id="'+ this._id_datepicker_prev +'" class="prev"> < </td><td id="'+ this._id_datepicker_hdr +'" class="header"></td><td id="'+ this._id_datepicker_next +'" class="next"> > </td><td id="'+ this._id_datepicker_next_year +'" class="next_year"> >> </td></tr></table></div><div class="datepicker-calendar"><table class="body"><tbody id="'+ this._id_datepicker +'-tbody"></tbody></table></div><div id="'+ this._id_datepicker_ftr +'" class="datepicker-footer"></div>';
+    this._div.innerHTML = '<div class="datepicker-header"><table class="header"><tr><td id="'+ this._id_datepicker_prev_year +'" class="prev-year"> << </td><td id="'+ this._id_datepicker_prev +'" class="prev"> < </td><td id="'+ this._id_datepicker_hdr +'" class="header"></td><td id="'+ this._id_datepicker_next +'" class="next"> > </td><td id="'+ this._id_datepicker_next_year +'" class="next-year"> >> </td></tr></table></div><div class="datepicker-calendar"><table class="body"><tbody id="'+ this._id_datepicker +'-tbody"></tbody></table></div><div id="'+ this._id_datepicker_ftr +'" class="datepicker-footer"></div>';
 
     /* Build the datepicker icon */
     var datepickeropener = Builder.node('table',{className : "datepicker-opener-table", id: this._id_datepicker + '_image'});
     var con = Builder.node('tr',{},[
-        Builder.node('td',{className : "datepicker-opener", id : "datepicker-opener-"+ this._relative})
+      Builder.node('td',{className : "datepicker-opener", id : "datepicker-opener-"+ this._relative})
     ]);
     // insert into TBODY
-    if (datepickeropener.childNodes[0] != undefined) {
+    if (datepickeropener.childNodes[0] !== undefined) {
       datepickeropener.childNodes[0].appendChild(con);
     } else {
       datepickeropener.appendChild(con);
@@ -332,9 +336,6 @@ DatePicker.prototype  = {
     this.insertAfter($(this._relative).parentNode,datepickeropener,$(this._relative));
     /* End Build the datepicker icon */
 
-    /* finally declare the event listener on input field */
-    //Event.observe(this._relative, 'click', this.click.bindAsEventListener(this), false);
-
     /* need to append on body when doc is loaded for IE */
     document.observe('dom:loaded', this.load.bindAsEventListener(this), false);
 
@@ -423,7 +424,8 @@ DatePicker.prototype  = {
   click : function () {
 
     /* init the datepicker if it doesn't exists */
-    if ( $(this._id_datepicker) == null ) this.load();
+    if ($(this._id_datepicker) == null)
+      this.load();
     var a_pos = Element.cumulativeOffset($(this._relative));
     this.setPosition(a_pos[1], a_pos[0]);
     if (!this._isPositionned && this._relativePosition) {
@@ -440,8 +442,8 @@ DatePicker.prototype  = {
       this._redrawCalendar();
     }
 
-    /* eval the clickCallback function */
-    eval(this._clickCallback());
+    /* call the clickCallback function */
+    this._clickCallback();
 
     /* Effect toggle to fade-in / fade-out the datepicker */
     if ( this._enableShowEffect ) {
@@ -484,7 +486,7 @@ DatePicker.prototype  = {
     } else {
       $(this._id_datepicker).hide();
     }
-    eval(this._afterClose());
+    this._afterClose();
   },
 
   /**
@@ -516,7 +518,7 @@ DatePicker.prototype  = {
    * _getMonthDays : given the year and month find the number of days.
    */
   _getMonthDays : function ( year, month ) {
-    if (((0 == (year%4)) && ((0 != (year%100)) || (0 == (year%400)))) && (month == 1))
+    if ((((year%4) === 0) && (((year%100) !== 0) || ((year%400) !== 0))) && (month === 1))
       return 29;
     return this._daysInMonth[month];
   },
@@ -526,7 +528,6 @@ DatePicker.prototype  = {
    */
   _buildCalendar : function () {
 
-    var _self = this;
     var tbody = $(this._id_datepicker +'-tbody');
     try {
       while ( tbody.hasChildNodes() )
@@ -559,10 +560,9 @@ DatePicker.prototype  = {
     var d = new Date(this._current_year, this._current_mon, 1, 12);
 
     /* start the day list on monday */
-    var startIndex  = ( !d.getDay() ) ? 6 : d.getDay() - 1;
-    var nbDaysInMonth = this._getMonthDays(
-    this._current_year, this._current_mon);
-    var daysIndex = 1;
+    var startIndex    = ( !d.getDay() ) ? 6 : d.getDay() - 1;
+    var nbDaysInMonth = this._getMonthDays(this._current_year, this._current_mon);
+    var daysIndex     = 1;
 
     for ( var j = startIndex; j < 7; j++ ) {
       a_d[0][j] = {
@@ -592,7 +592,7 @@ DatePicker.prototype  = {
           d : daysIndex,
           m : currentMonth,
           y : currentYear,
-          c : ( switchNextMonth ) ? 'outbound' : (((daysIndex == this._todayDate.getDate()) && (this._current_mon  == this._todayDate.getMonth()) && (this._current_year == this._todayDate.getFullYear())) ? 'today' : null)
+          c : (switchNextMonth ? 'outbound' : (((daysIndex === this._todayDate.getDate()) && (this._current_mon  === this._todayDate.getMonth()) && (this._current_year === this._todayDate.getFullYear())) ? 'today' : null))
         };
         daysIndex++;
 
@@ -631,15 +631,16 @@ DatePicker.prototype  = {
 
         /* on onclick : rebuild date value from id of current cell */
         var _curDate = new Date();
+        var _res;
 
         _curDate.setFullYear(h_ij["y"], h_ij["m"], h_ij["d"]);
         if ( this._disablePastDate || this._disableFutureDate ) {
           if ( this._disablePastDate ) {
-            var _res  = ( _curDate >= this._todayDate ) ? true : false;
+            _res  = ( _curDate >= this._todayDate ) ? true : false;
             this._bindCellOnClick( td, true, _res, h_ij["c"] );
           }
           if ( this._disableFutureDate ) {
-            var _res  = ( this._todayDate.getTime() + this._oneDayInMs > _curDate.getTime() ) ? true : false;
+            _res  = ( this._todayDate.getTime() + this._oneDayInMs > _curDate.getTime() ) ? true : false;
             this._bindCellOnClick( td, true, _res,  h_ij["c"] );
           }
         } else {
@@ -662,7 +663,7 @@ DatePicker.prototype  = {
       if ( compareresult ) {
         doBind  = true;
       } else {
-        td.className= ( h_ij_c ) ? 'nclick_outbound' : 'nclick';
+        td.className= ( h_ij_c ) ? 'nclick-outbound' : 'nclick';
       }
     } else {
       doBind = true;
